"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MMSAudio = void 0;
const AbstractAudioMessage_1 = require("../AbstractAudioMessage");
/**
 * Represents an audio message for the MMS channel.
 *
 * @group MMS
 */
class MMSAudio extends AbstractAudioMessage_1.AbstractAudioMessage {
    channel;
    /**
     * Send an MMS audio message.
     *
     * @param {MessageParamsAudio} params - The parameters for creating the audio message.
     *
     * @example
     * ```ts
     * import { MMSAudio } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MMSAudio({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  audio: {
     *    url: 'https://example.com/audio.mp3',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'mms';
    }
}
exports.MMSAudio = MMSAudio;
//# sourceMappingURL=MMSAudio.js.map