"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MMSVcard = void 0;
const AbstractVcardMessage_1 = require("../AbstractVcardMessage");
/**
 * Represents a vCard message for the MMS channel.
 *
 * @group MMS
 */
class MMSVcard extends AbstractVcardMessage_1.AbstractVcardMessage {
    channel;
    /**
     * Send an MMS vCard message.
     *
     * @param {MessageParamsVcard} params - The parameters for creating the vCard message.
     * @example
     * ```ts
     * import { MMSVcard } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MMSVcard({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  vcard: {
     *    url: 'https://example.com/vcard.vcf',
     *    caption: 'Download my contact information',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'mms';
    }
}
exports.MMSVcard = MMSVcard;
//# sourceMappingURL=MMSVcard.js.map