"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessengerText = void 0;
const AbstractTextMessage_1 = require("../AbstractTextMessage");
/**
 * Represents a text message for the Messenger channel.
 *
 * @group Messenger
 */
class MessengerText extends AbstractTextMessage_1.AbstractTextMessage {
    /**
     * The channel for this message (always 'messenger').
     */
    channel;
    /**
     * The messenger information for this message.
     */
    messenger;
    /**
     * Sends a text message to the Facebook Messenger channel.
     *
     * @param {MessengerTextParams} params - The parameters for creating a Messenger text message.
     *
     * @example
     * ```ts
     * import { MessengerText } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MessengerText({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  text: 'Hello world',
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.messenger = params.messenger;
        this.channel = 'messenger';
    }
}
exports.MessengerText = MessengerText;
//# sourceMappingURL=MessengerText.js.map