import { AbstractVideoMessage } from '../AbstractVideoMessage';
import { ViberVideoParams } from '../../types';
/**
 * Represents a video message for the Viber Service channel.
 *
 * @group Viber
 */
export declare class ViberVideo extends AbstractVideoMessage implements ViberVideoParams {
    channel: 'viber_service';
    viberService: {
        duration: string;
        fileSize: string;
    } & {
        action: import("../../types").ViberAction;
    } & import("../../types").ViberService;
    /**
     * Send a video message using the Viber Service channel.
     *
     * @param {ViberVideoParams} params - The parameters for the ViberVideo message.
     * @example
     * ```ts
     * import { ViberVideo } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new ViberVideo({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  text: 'Hello world',
     *  video: {
     *    url: 'https://my-host.com/my-video.mp4',
     *  },
     *  viberService: {
     *    action: {
     *      url: 'https://my-host.com/my-path',
     *      text: 'My button text',
     *    },
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params: ViberVideoParams);
}
//# sourceMappingURL=ViberVideo.d.ts.map