"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhatsAppAudio = void 0;
const AbstractAudioMessage_1 = require("../AbstractAudioMessage");
/**
 * Represents an audio message for WhatsApp.
 *
 * @group WhatsApp
 */
class WhatsAppAudio extends AbstractAudioMessage_1.AbstractAudioMessage {
    channel;
    context;
    /**
     * Sends an audio message to a WhatsApp user.
     *
     * @param {WhatsAppAudioParams} params - The parameters for creating a WhatsApp audio message.
     * @example
     * ```ts
     * import { WhatsAppAudio } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppAudio({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  audio: {
     *    url: 'https://example.com/audio.mp3',
     *    caption: 'This is an audio message',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'whatsapp';
        if (params.context) {
            this.context = params.context;
        }
    }
}
exports.WhatsAppAudio = WhatsAppAudio;
//# sourceMappingURL=WhatsAppAudio.js.map