"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhatsAppReaction = void 0;
const AbstractMessage_1 = require("../AbstractMessage");
/**
 * Represents a reaction message for WhatsApp.
 *
 * @group WhatsApp
 */
class WhatsAppReaction extends AbstractMessage_1.AbstractMessage {
    channel;
    messageType;
    reaction;
    context;
    /**
     * Sends a reaction message to a WhatsApp user.
     *
     * @param {WhatsAppReactionParams} params - The parameters for creating a WhatsApp reaction message.
     * @example
     * Send a reaction
     * ```ts
     * import { WhatsAppReaction } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppReaction({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  reaction: {
     *    action: 'react',
     *    emoji: '😍',
     *  }
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     *
     * @example
     * Remove reaction
     * ```ts
     * import { WhatsAppReaction } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppReaction({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  reaction: {
     *    action: 'unreact',
     *  }
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'whatsapp';
        this.messageType = 'reaction';
        this.reaction = params.reaction;
        if (params.context) {
            this.context = params.context;
        }
    }
}
exports.WhatsAppReaction = WhatsAppReaction;
//# sourceMappingURL=WhatsAppReaction.js.map