"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWT = void 0;
const tokenGenerate_1 = require("./tokenGenerate");
const verifySignature_1 = require("./verifySignature");
/**
 * Class implementing the JWTInterface for JWT operations.
 *
 * @ignore
 * @deprecated Using the class is no longer needed
 */
class JWT {
    /**
     * Generates a JWT token.
     *
     * @param {string} applicationId - The application ID.
     * @param {string | Buffer} privateKey - The private key for signing the JWT.
     * @param {GeneratorOptions} [opts] - Optional parameters for token generation.
     * @return {string} - The generated JWT token.
     */
    tokenGenerate(applicationId, privateKey, opts) {
        return (0, tokenGenerate_1.tokenGenerate)(applicationId, privateKey, opts);
    }
    /**
     * Verifies the signature of a JWT token.
     *
     * @param {string} jwt - The JWT token to verify.
     * @param {string | Buffer} privateKey - The private key used for verification.
     * @return {boolean} - True if the signature is valid, false otherwise.
     */
    verifySignature(jwt, privateKey) {
        return (0, verifySignature_1.verifySignature)(jwt, privateKey);
    }
    /**
     * Validates the options provided for JWT generation.
     *
     * @param {GeneratorOptions} [opts] - The options to validate.
     * @return {Claims} - The validated claims.
     */
    validateOptions(opts) {
        return (0, tokenGenerate_1.validateOptions)(opts);
    }
}
exports.JWT = JWT;
//# sourceMappingURL=jwt.js.map